Crate netcdf_core

Crate netcdf_core 

Shared NetCDF data model used by reader and writer crates.

Structs

NcAttribute
A NetCDF attribute.
NcCompoundField
A field within a compound type.
NcDimension
A NetCDF dimension.
NcEnumMember
A named member of a NetCDF-4 enum type.
NcGroup
A NetCDF group.
NcSliceInfo
Hyperslab selection for reading/writing slices of NetCDF variables.
NcVariable
A NetCDF variable. The offset fields are public for reader/writer crate interoperability; they are not portable semantic metadata.

Enums

Error
Errors produced by shared NetCDF model helpers.
NcAttrValue
A NetCDF attribute value.
NcFormat
NetCDF file format.
NcIntegerValue
A typed integer value used by NetCDF-4 enum definitions and values.
NcMetadataMode
NetCDF-4 metadata reconstruction policy.
NcSliceInfoElem
A single dimension selection within a hyperslab.
NcType
NetCDF data types.

Constants

NC_BYTE
NetCDF classic type codes.
NC_CHAR
NC_DOUBLE
NC_FILL_BYTE
Default fill value for NC_BYTE variables when prefilled data is needed.
NC_FILL_CHAR
Default fill value for NC_CHAR variables when prefilled data is needed.
NC_FILL_DOUBLE
Default fill value for NC_DOUBLE variables when prefilled data is needed.
NC_FILL_FLOAT
Default fill value for NC_FLOAT variables when prefilled data is needed.
NC_FILL_INT
Default fill value for NC_INT variables when prefilled data is needed.
NC_FILL_INT64
Default fill value for NC_INT64 variables when prefilled data is needed.
NC_FILL_SHORT
Default fill value for NC_SHORT variables when prefilled data is needed.
NC_FILL_UBYTE
Default fill value for NC_UBYTE variables when prefilled data is needed.
NC_FILL_UINT
Default fill value for NC_UINT variables when prefilled data is needed.
NC_FILL_UINT64
Default fill value for NC_UINT64 variables when prefilled data is needed.
NC_FILL_USHORT
Default fill value for NC_USHORT variables when prefilled data is needed.
NC_FLOAT
NC_INT
NC_INT64
NC_SHORT
NC_UBYTE
NC_UINT
NC_UINT64
NC_USHORT

Functions

checked_mul_u64
checked_shape_elements
checked_usize_from_u64
pad_to_4
Round up to the next 4-byte boundary.
padding_to_4
Compute the amount of padding needed to reach a 4-byte boundary.

Type Aliases

Result