Shared NetCDF data model used by reader and writer crates.
Structs
- NcAttribute
- A NetCDF attribute.
- NcCompound
Field - A field within a compound type.
- NcDimension
- A NetCDF dimension.
- NcEnum
Member - A named member of a NetCDF-4 enum type.
- NcGroup
- A NetCDF group.
- NcSlice
Info - Hyperslab selection for reading/writing slices of NetCDF variables.
- NcVariable
- A NetCDF variable. The offset fields are public for reader/writer crate interoperability; they are not portable semantic metadata.
Enums
- Error
- Errors produced by shared NetCDF model helpers.
- NcAttr
Value - A NetCDF attribute value.
- NcFormat
- NetCDF file format.
- NcInteger
Value - A typed integer value used by NetCDF-4 enum definitions and values.
- NcMetadata
Mode - NetCDF-4 metadata reconstruction policy.
- NcSlice
Info Elem - A single dimension selection within a hyperslab.
- NcType
- NetCDF data types.
Constants
- NC_BYTE
- NetCDF classic type codes.
- NC_CHAR
- NC_
DOUBLE - NC_
FILL_ BYTE - Default fill value for NC_BYTE variables when prefilled data is needed.
- NC_
FILL_ CHAR - Default fill value for NC_CHAR variables when prefilled data is needed.
- NC_
FILL_ DOUBLE - Default fill value for NC_DOUBLE variables when prefilled data is needed.
- NC_
FILL_ FLOAT - Default fill value for NC_FLOAT variables when prefilled data is needed.
- NC_
FILL_ INT - Default fill value for NC_INT variables when prefilled data is needed.
- NC_
FILL_ INT64 - Default fill value for NC_INT64 variables when prefilled data is needed.
- NC_
FILL_ SHORT - Default fill value for NC_SHORT variables when prefilled data is needed.
- NC_
FILL_ UBYTE - Default fill value for NC_UBYTE variables when prefilled data is needed.
- NC_
FILL_ UINT - Default fill value for NC_UINT variables when prefilled data is needed.
- NC_
FILL_ UINT64 - Default fill value for NC_UINT64 variables when prefilled data is needed.
- NC_
FILL_ USHORT - Default fill value for NC_USHORT variables when prefilled data is needed.
- NC_
FLOAT - NC_INT
- NC_
INT64 - NC_
SHORT - NC_
UBYTE - NC_UINT
- NC_
UINT64 - NC_
USHORT
Functions
- checked_
mul_ u64 - checked_
shape_ elements - checked_
usize_ from_ u64 - pad_
to_ 4 - Round up to the next 4-byte boundary.
- padding_
to_ 4 - Compute the amount of padding needed to reach a 4-byte boundary.